#SLIP-0044 : Registered coin types for BIP-0044

```
Number:  SLIP-0044
Title:   Registered coin types for BIP-0044
Type:    Standard
Status:  Draft
Authors: Pavol Rusnak <stick@satoshilabs.com>
         Marek Palatinus <slush@satoshilabs.com>
Created: 2014-07-09
```

##Abstract

BIP-0044 defines a logical hierarchy for deterministic wallets.
Level 2 of the hierarchy describes a coin type in use.

##Motivation

BIP repository does not want to deal with assigning the values for various
coin types different than Bitcoin so we propose this SLIP to become such body.

##Registered coin types

These are the registered coin types for usage in level 2 of BIP44 described in chapter "Coin type".

All these constants are used as hardened derivation.

index | hexa       | coin
------|------------|-----------------------------------
    0 | 0x80000000 | Bitcoin
    1 | 0x80000001 | Testnet (all coins)
    2 | 0x80000002 | Litecoin
    3 | 0x80000003 | Dogecoin
    4 | 0x80000004 | Reddcoin
    5 | 0x80000005 | Dash (ex Darkcoin)
    6 | 0x80000006 | Peercoin
    7 | 0x80000007 | Namecoin
    8 | 0x80000008 | Feathercoin
    9 | 0x80000009 | Counterparty
   10 | 0x8000000a | Blackcoin
   11 | 0x8000000b | NuShares
   12 | 0x8000000c | NuBits
   13 | 0x8000000d | Mazacoin
   14 | 0x8000000e | Viacoin
   15 | 0x8000000f | ClearingHouse
   16 | 0x80000010 | Rubycoin
   17 | 0x80000011 | Groestlcoin
   18 | 0x80000012 | Digitalcoin
   19 | 0x80000013 | Cannacoin
   20 | 0x80000014 | DigiByte
   21 | 0x80000015 | [Open Assets](https://github.com/OpenAssets/open-assets-protocol)
   22 | 0x80000016 | Monacoin
   23 | 0x80000017 | Clams
   24 | 0x80000018 | Primecoin
   25 | 0x80000019 | Neoscoin
   26 | 0x8000001a | Jumbucks
   27 | 0x8000001b | ziftrCOIN
   28 | 0x8000001c | Vertcoin
   29 | 0x8000001d | NXT
   30 | 0x8000001e | Burst
   31 | 0x8000001f | MonetaryUnit
   32 | 0x80000020 | Zoom
   33 | 0x80000021 | Vpncoin
   34 | 0x80000022 | [Canada eCoin](https://github.com/Canada-eCoin/)
   35 | 0x80000023 | ShadowCash
   36 | 0x80000024 | [ParkByte](https://github.com/parkbyte/)
   37 | 0x80000025 | Pandacoin
   38 | 0x80000026 | StartCOIN
   49 | 0x80000031 | Global Currency Reserve (GCRcoin)
   50 | 0x80000032 | [Novacoin](https://github.com/novacoin-project/novacoin)
   51 | 0x80000033 | [Asiacoin](https://github.com/AsiaCoin/AsiaCoinFix)
   52 | 0x80000034 | [Bitcoindark](https://github.com/jl777/btcd)
   53 | 0x80000035 | [Dopecoin](https://github.com/dopecoin-dev/DopeCoinV3)
   54 | 0x80000036 | [Templecoin](https://github.com/9cat/templecoin)
   55 | 0x80000037 | [AIB](https://github.com/iobond/aib)
   60 | 0x8000003c | [Ether](https://ethereum.org/ether)
   64 | 0x80000040 | [Open Chain](https://github.com/openchain/)
   69 | 0x80000045 | [OKCash](https://github.com/okcashpro/)
   77 | 0x8000004d | [DogecoinDark](https://github.com/doged/)
   78 | 0x8000004e | [Electronic Gulden](https://egulden.org/)
   79 | 0x8000004f | [ClubCoin](https://clubcoin.co/)
   80 | 0x80000050 | [RichCoin](https://richcoin.us/)
   81 | 0x80000051 | [Potcoin](http://potcoin.com/)
   82 | 0x80000052 | Quarkcoin
   83 | 0x80000053 | Terracoin
   84 | 0x80000054 | Gridcoin
   85 | 0x80000055 | [Auroracoin](http://auroracoin.is/)
   86 | 0x80000056 | IXCoin
   87 | 0x80000057 | [Gulden](https://Gulden.com/)
   88 | 0x80000058 | [BitBean](http://bitbean.org/)
   89 | 0x80000059 | [Bata](http://bata.io/)
   90 | 0x8000005a | [Myriadcoin](http://myriadcoin.org)
   91 | 0x8000005b | [BitSend](http://bitsend.info)
  100 | 0x80000064 | [BigUp](https://github.com/BigUps/)
  101 | 0x80000065 | [GameCredits](https://github.com/Gamecredits-Universe/)
  128 | 0x80000080 | [Monero](https://getmonero.org/)

Coin types will be added only if there is a wallet implementing BIP-0044 for desired coin.

##Libraries

* [BIP44-constants](https://www.npmjs.com/package/bip44-constants) ([source](http://github.com/bitcoinjs/bip44-constants)) JavaScript package with described coin types

##References

- [BIP-0044: Multi-Account Hierarchy for Deterministic Wallets](https://github.com/bitcoin/bips/blob/master/bip-0044.mediawiki)
